@@ -1,8 +1,8 @@
 #!/usr/bin/env bash
 
-IMAGE="impish-preinstalled-desktop-arm64+raspi.img"
+IMAGE="jammy-preinstalled-desktop-arm64+raspi.img"
 RELEASE="https://cdimage.ubuntu.com/daily-preinstalled/current"
-RELEASEIMAGE="impish-budgie-preinstalled-desktop-arm64+raspi.img"
+RELEASEIMAGE="jammy-budgie-preinstalled-desktop-arm64+raspi.img"
 MOUNT="/mnt/pi"
 NAMESERVER=1.1.1.1
 
@@ -20,11 +20,12 @@ if [ ! -f "/usr/bin/qemu-arm-static" ]; then
 fi
 
 CURRENT_DIR=$(pwd)
-if [ ! -f "$IMAGE.xz" ]; then
-  echo "Downloading image"
-  sudo -u $SUDO_USER wget $RELEASE/$IMAGE.xz
-fi
 if [ ! -f "$IMAGE" ]; then
+  if [ ! -f "$IMAGE.xz" ]; then
+    echo "Downloading image"
+    sudo -u $SUDO_USER wget $RELEASE/$IMAGE.xz
+  fi
+
   echo "Uncompressing image"
   sudo -u $SUDO_USER xz -d -v $IMAGE.xz
 fi
@@ -58,5 +59,5 @@ umount $MOUNT
 rmdir $MOUNT
 mv $IMAGE $RELEASEIMAGE
 
-# Next line commented because it takes a long time to recompress
-xz -v --threads=0 $RELEASEIMAGE
+# Next line will take a long time to recompress unless you are using a 16 core NVME based Ryzen 7 or better machine!
+xz -v -9 --threads=0 $RELEASEIMAGE
