@@ -34,6 +34,8 @@ cp ubuntubudgiecompact.layout ${PREFIX_DIR}/usr/share/budgie-desktop/layouts
 cp reset.sh ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
 cp budgie-xrdp.sh ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
 cp budgie-ssh.sh ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
+cp budgie-vnc.sh ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
+cp x11vnc.service ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
 cp pi-kmsmode.sh ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
 cp budgie-autologin.sh ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
 cp *.py ${PREFIX_DIR}/usr/lib/budgie-desktop/arm
