@@ -1,11 +1,13 @@
+import pwd
 import socket
 import subprocess
 import psutil
 import gi
 import getpass
 gi.require_version("Gtk", "3.0")
-from gi.repository import GLib, Gio
+from gi.repository import GLib, Gio, Gtk
 import hint
+import vncdialog
 
 
 class Remote:
@@ -15,6 +17,7 @@ class Remote:
     FINDPI = "/usr/lib/budgie-desktop/arm/findmypiserver.py"
     AUTOLOGIN = "/usr/lib/budgie-desktop/arm/budgie-autologin.sh"
     LIGHTDMCONF = "/etc/lightdm/lightdm.conf"
+    VNC = "/usr/lib/budgie-desktop/arm/budgie-vnc.sh"
 
     def __init__(self, builder, device):
         self.iplabel = builder.get_object("IPLabel")
@@ -24,18 +27,13 @@ class Remote:
         self.run_findmypi = self.gsettings.get_boolean('enableserver')
         app_statuslabel = builder.get_object("AppStatusLabel")
 
-        if GLib.find_program_in_path("pipewire") == None:
-            self.found_grd = False
-        else:
-            self.found_grd = True
-
         self.vncbutton = builder.get_object("VNCButton")
         self.vncbutton.connect('clicked', self.vncbuttonclicked)
-        self.vncbutton.set_visible(self.found_grd)
 
         self.xrdpbutton = builder.get_object("XRDPButton")
         self.xrdpbutton.connect('clicked', self.xrdpbuttonclicked)
 
+        self.vncstatuslabel = builder.get_object("VNCStatusLabel")
         self.xrdpstatuslabel = builder.get_object("XRDPStatusLabel")
         self.sshstatuslabel = builder.get_object("SSHStatusLabel")
         self.findmypistatuslabel = builder.get_object("FindMyPiStatusLabel")
@@ -69,16 +67,21 @@ class Remote:
             self.findmypistatuslabel.set_text("Server is inactive")
 
         self.run_remote(self.xrdpstatuslabel, self.XRDP, 'status')
-        if not self.found_grd:
-            self.run_remote(self.sshstatuslabel, self.SSH, 'status')
+        self.run_remote(self.sshstatuslabel, self.SSH, 'status')
 
-    def run_remote(self, label, connection, param, root=False):
+        self.run_remote(self.vncstatuslabel, self.VNC, 'status')
+
+    def run_remote(self, label, connection, param, root=False, alt_param = []):
 
         if root:
             args = ['pkexec', connection, param]
         else:
             args = [connection, param]
 
+        if alt_param != []:
+            # VNC setup needs extra params, probably rework this in the future
+            args += (alt_param)
+
         try:
             output = subprocess.check_output(args,
                 stderr=subprocess.STDOUT).decode("utf-8")
@@ -98,11 +101,6 @@ class Remote:
             self.run_remote(self.xrdpstatuslabel, self.XRDP, 'enable')
 
     def sshbuttonclicked(self, *args):
-        if self.found_grd:
-            # with gnome-remote-desktop ssh is provided
-            self.open_sharing()
-            return
-
         if 'service is active' in self.sshstatuslabel.get_text():
             self.run_remote(self.sshstatuslabel, self.SSH, 'disable')
         else:
@@ -120,12 +118,37 @@ class Remote:
 
     def open_sharing(self):
         try:
-            subprocess.run(['gnome-control-center', 'sharing'])
+            subprocess.run(['budgie-control-center', 'sharing'])
         except subprocess.CalledProcessError:
             pass
 
+    def activate_vnc(self, extra_args=[], disable=False):
+        if disable:
+            self.run_remote(self.vncstatuslabel, self.VNC, 'disable', root=True)
+        else:
+            self.run_remote(self.vncstatuslabel, self.VNC, 'setup', root=True, alt_param=extra_args)
+        self.run_remote(self.vncstatuslabel,self.VNC,'status')
+        return False
+
     def vncbuttonclicked(self, *args):
-        self.open_sharing()
+        stopservice = 'vnc service is active' in self.vncstatuslabel.get_text()
+        self.vncstatuslabel.set_text("Please wait...")
+        if stopservice:
+            # Sometimes, x11vnc takes a while to stop, making app seem unresponsive
+            # Timeout allows the "please wait" message to appear
+            GLib.timeout_add(10,self.activate_vnc, [], True)
+        else:
+            # get the ip (needed to restrict VNC to local subnet)
+            subnet =".".join(self.get_ip().split(".", 3)[:-1]) + "."
+            pwdialog = vncdialog.VncDialog()
+            response = pwdialog.run()
+            if response == Gtk.ResponseType.OK:
+                password = pwdialog.get_result()
+                pwdialog.destroy()
+                GLib.idle_add(self.activate_vnc, [password, subnet], False)
+            else:
+                self.run_remote(self.vncstatuslabel, self.VNC, 'status')
+                pwdialog.destroy()
 
     def autologintoggled(self, button):
         should_enable = button.get_active()
@@ -192,7 +215,7 @@ class Remote:
     def findmypi_server(self, kill=False):
         # Return True if server is running, also will kill server if kill=True
         for proc in psutil.process_iter():
-            if (len(proc.cmdline()) > 1 and "python" in proc.cmdline()[0] 
+            if (len(proc.cmdline()) > 1 and "python" in proc.cmdline()[0]
                                    and "findmypiserver" in proc.cmdline()[1]):
                 if kill:
                     proc.terminate()
